summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/pref_names.cc4
-rw-r--r--chrome/common/pref_names.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/chrome/common/pref_names.h b/chrome/common/pref_names.h
index 34af347..4a54f05 100644
--- a/chrome/common/pref_names.h
+++ b/chrome/common/pref_names.h
@@ -207,7 +207,7 @@ extern const char kLanguageXkbAutoRepeatEnabled[];
extern const char kLanguageXkbAutoRepeatDelay[];
extern const char kLanguageXkbAutoRepeatInterval[];
extern const char kLanguagePreferredVirtualKeyboard[];
-extern const char kAccessibilityEnabled[];
+extern const char kSpokenFeedbackEnabled[];
extern const char kLabsAdvancedFilesystemEnabled[];
extern const char kLabsMediaplayerEnabled[];
extern const char kEnableScreenLock[];
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index 90b56fd..22105f3 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -577,8 +577,8 @@ const char kLanguageXkbAutoRepeatInterval[] =
const char kLanguagePreferredVirtualKeyboard[] =
"settings.language.preferred_virtual_keyboard";
-// A boolean pref which determines whether accessibility is enabled.
-const char kAccessibilityEnabled[] = "settings.accessibility";
+// A boolean pref which determines whether spoken feedback is enabled.
+const char kSpokenFeedbackEnabled[] = "settings.accessibility";
// A boolean pref which turns on Advanced Filesystem
// (USB support, SD card, etc).